#[repr(C)]pub struct PacketOutputVtbl<Perms: PacketPerms> {
pub output: unsafe extern "C" fn(OutputRef<'static, Perms>, PacketView<'static, Perms>, Option<NonZeroI32>),
}Expand description
Describes operations that can be performed on a packet output object.
Fields
output: unsafe extern "C" fn(OutputRef<'static, Perms>, PacketView<'static, Perms>, Option<NonZeroI32>)Output handler.
This function will be invoked whenever a packet view is returned to the final destination.
Packet::on_output will be called before this function is invoked, but before the
potential waker (of the last packet view standing) gets triggered.
TODO: make this a polled async function.