TransferredPacket

Struct TransferredPacket 

pub struct TransferredPacket<T: PacketPerms>(/* private fields */);
Represents the state of the packet that has already had data transferred to.

This struct is marked as must_use, because the intention is for the backend to be explicit about when the packet is dropped and released to the user. Since bound packets may call a function that generates more I/O requests, it is important to drop the packet outside critical sections.