pub struct SeekableRef<'a, T, Param> { /* private fields */ }Trait Implementations
Sourceimpl<T: PacketIo<Perms, Param>, Perms: PacketPerms, Param: Debug> PacketIo<Perms, Param> for SeekableRef<'_, T, Param>
impl<T: PacketIo<Perms, Param>, Perms: PacketPerms, Param: Debug> PacketIo<Perms, Param> for SeekableRef<'_, T, Param>
Sourcefn send_io(&self, param: Param, view: BoundPacketView<Perms>)
fn send_io(&self, param: Param, view: BoundPacketView<Perms>)
Send I/O request to the backend. Read more
Sourceimpl<'a, T> Read for SeekableRef<'a, T, u64>
impl<'a, T> Read for SeekableRef<'a, T, u64>
Sourcefn read(&mut self, buf: &mut [u8]) -> Result<usize>
fn read(&mut self, buf: &mut [u8]) -> Result<usize>
Pull some bytes from this source into the specified buffer, returning
how many bytes were read. Read more
Sourcefn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize>
fn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize>
Reads all bytes until EOF in this source, placing them into
buf. Read more1.36.0 · Sourcefn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize, Error>
fn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize, Error>
Like
read, except that it reads into a slice of buffers. Read moreSourcefn is_read_vectored(&self) -> bool
fn is_read_vectored(&self) -> bool
🔬This is a nightly-only experimental API. (
can_vector)1.0.0 · Sourcefn read_to_string(&mut self, buf: &mut String) -> Result<usize, Error>
fn read_to_string(&mut self, buf: &mut String) -> Result<usize, Error>
Reads all bytes until EOF in this source, appending them to
buf. Read more1.6.0 · Sourcefn read_exact(&mut self, buf: &mut [u8]) -> Result<(), Error>
fn read_exact(&mut self, buf: &mut [u8]) -> Result<(), Error>
Reads the exact number of bytes required to fill
buf. Read moreSourcefn read_buf(&mut self, buf: BorrowedCursor<'_>) -> Result<(), Error>
fn read_buf(&mut self, buf: BorrowedCursor<'_>) -> Result<(), Error>
🔬This is a nightly-only experimental API. (
read_buf)Pull some bytes from this source into the specified buffer. Read more
Sourcefn read_buf_exact(&mut self, cursor: BorrowedCursor<'_>) -> Result<(), Error>
fn read_buf_exact(&mut self, cursor: BorrowedCursor<'_>) -> Result<(), Error>
🔬This is a nightly-only experimental API. (
read_buf)Reads the exact number of bytes required to fill
cursor. Read more1.0.0 · Sourcefn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,
fn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,
Creates a “by reference” adapter for this instance of
Read. Read more1.0.0 · Sourcefn chain<R>(self, next: R) -> Chain<Self, R>
fn chain<R>(self, next: R) -> Chain<Self, R>
Creates an adapter which will chain this stream with another. Read more
Sourceimpl<'a, T> Seek for SeekableRef<'a, T, u64>
impl<'a, T> Seek for SeekableRef<'a, T, u64>
Sourcefn seek(&mut self, pos: SeekFrom) -> Result<u64>
fn seek(&mut self, pos: SeekFrom) -> Result<u64>
Seek to an offset, in bytes, in a stream. Read more
Sourcefn stream_position(&mut self) -> Result<u64>
fn stream_position(&mut self) -> Result<u64>
Returns the current seek position from the start of the stream. Read more
Sourceimpl<T, Param: Copy> StreamPos<Param> for SeekableRef<'_, T, Param>
impl<T, Param: Copy> StreamPos<Param> for SeekableRef<'_, T, Param>
Sourceimpl<'a, T, Param, __Pos: 'static> SyncIoRead<__Pos> for SeekableRef<'a, T, Param>
impl<'a, T, Param, __Pos: 'static> SyncIoRead<__Pos> for SeekableRef<'a, T, Param>
fn read_all<'a>( &'a self, pos: Pos, packet: impl IntoPacket<'a, Write>, ) -> Result<(), Error>
fn read_into<'a, T: Pod>( &'a self, pos: Pos, data: &'a mut MaybeUninit<T>, ) -> Result<(), Error>
fn read<T: Pod>(&self, pos: Pos) -> Result<T, Error>
fn read_to_end<'a>(&'a self, pos: Pos, buf: &'a mut Vec<u8>) -> Option<usize>
Sourceimpl<'a, T, Param, __Pos: 'static> SyncIoWrite<__Pos> for SeekableRef<'a, T, Param>
impl<'a, T, Param, __Pos: 'static> SyncIoWrite<__Pos> for SeekableRef<'a, T, Param>
Sourceimpl<'a, T> Write for SeekableRef<'a, T, u64>
impl<'a, T> Write for SeekableRef<'a, T, u64>
Sourcefn write(&mut self, buf: &[u8]) -> Result<usize>
fn write(&mut self, buf: &[u8]) -> Result<usize>
Writes a buffer into this writer, returning how many bytes were written. Read more
Sourcefn flush(&mut self) -> Result<()>
fn flush(&mut self) -> Result<()>
Flushes this output stream, ensuring that all intermediately buffered
contents reach their destination. Read more
Sourcefn is_write_vectored(&self) -> bool
fn is_write_vectored(&self) -> bool
🔬This is a nightly-only experimental API. (
can_vector)1.0.0 · Sourcefn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
fn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
Attempts to write an entire buffer into this writer. Read more
Sourcefn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
fn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
🔬This is a nightly-only experimental API. (
write_all_vectored)Attempts to write multiple buffers into this writer. Read more