pub union PacketVtblRef<Perms: PacketPerms> {
pub tag: usize,
pub vtbl: &'static Perms,
}Expand description
Describes packet type.
If the value within this union is less than PacketVtblTag::Complex, then the packet is
simple, and tag should be accessed. Meanwhile, any other value implies the packet is a
complex one, and vtable should be accessed instead.
Fields
tag: usizevtbl: &'static PermsImplementations
Sourceimpl<Perms: PacketPerms> PacketVtblRef<Perms>
impl<Perms: PacketPerms> PacketVtblRef<Perms>
pub fn tag(&self) -> PacketVtblTag
pub fn vtbl(&self) -> Option<&'static Perms>